@@ -13,13 +13,12 @@ from pilas.actores import Explosion
 class Bomba(Animacion):
     "Representa una explosion para una bomba, dinamita etc..."
 
-    def __init__(self):
-        Animacion.__init__(self, pilas.imagenes.Grilla("bomba.png", 2), ciclica=True)
+    def __init__(self, x=0, y=0):
+        Animacion.__init__(self, pilas.imagenes.Grilla("bomba.png", 2), ciclica=True, x=x, y=y)
+        self.radio_de_colision = 25
+        self.aprender(pilas.habilidades.PuedeExplotar)
 
     def explotar(self):
-        explosion = Explosion()
-        explosion.x = self.x
-        explosion.y = self.y
-        explosion.escala = self.escala * 2
-
+        # Este metodo solo exite para compativilidad hacia atras.
         self.eliminar()
+
